==> 0.6.3rc1.zip: dmdirc-client/src/com/dmdirc/MessageTarget.java <==
/*
 * Copyright (c) 2006-2010 Chris Smith, Shane Mc Cormack, Gregory Holmes
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc;

import com.dmdirc.config.ConfigManager;

/**
 * Defines common methods for objects that you can send messages to (such as
 * channels and queries).
 *
 * @author Chris
 */
public abstract class MessageTarget extends WritableFrameContainer {

    /**
     * Creates a new MessageTarget.
     * 
     * @param icon The icon to use for this target
     * @param name The name of this target
     * @param config The config manager to use for this target
     * @since 0.6.3m2
     */
    public MessageTarget(final String icon, final String name, final ConfigManager config) {
        super(icon, name, config);
    }

    /**
     * Sends the specified string as an action (CTCP) to the target that this
     * object represents.
     *
     * @param action The action to send
     */
    public abstract void sendAction(final String action);

}

==> 0.6.6b1.zip: dmdirc-client/src/com/dmdirc/MessageTarget.java <==
/*
 * Copyright (c) 2006-2011 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc;

import com.dmdirc.commandparser.parsers.CommandParser;
import com.dmdirc.config.ConfigManager;

import java.util.Collection;

/**
 * Defines common methods for objects that you can send messages to (such as
 * channels and queries).
 */
public abstract class MessageTarget extends WritableFrameContainer {

    /**
     * Creates a new MessageTarget.
     *
     * @param icon The icon to use for this target
     * @param name The name of this target
     * @param title The title of this target
     * @param config The config manager to use for this target
     * @param parser The command parser for this container
     * @param components The UI components that this frame requires
     * @since 0.6.4
     */
    public MessageTarget(final String icon, final String name,
            final String title, final ConfigManager config,
            final CommandParser parser, final Collection<String> components) {
        super(icon, name, title, config, parser, components);
    }

    /**
     * Sends the specified string as an action (CTCP) to the target that this
     * object represents.
     *
     * @param action The action to send
     */
    public abstract void sendAction(final String action);

}
